Modules
Macros
- measures the execution time and prints it on the screen, example:
Structs
- is a part of the program, contains the context, i is capable of executing Use example:
Enums
- Values that retune the functions, tokens, keys i that also returns the exec of ProgramBlock