Module context
procc_
ll
0.3.1
Module context
Module Items
Structs
In crate procc_
ll
procc_ll
Module
context
Structs

Context
structure that contains all the data at the count level, saves the variables, tokens, functions and keys Use example :