macro_rules! measure_time_debug {
($expression:expr) => { ... };
}Expand description
measures the execution time and prints it on the screen, example:
use procc_ll::measure_time;
measure_time! ({println! ("hello ") });return the result of the code inside, only print the execution time if the RUST_LOG = debug