Crate procc_ll

Crate procc_ll 

Modules

context
token

Macros

measure_time
measure_time_debug
measures the execution time and prints it on the screen, example:

Structs

Program
is a part of the program, contains the context, i is capable of executing Use example:

Enums

Errors
Values
Values that retune the functions, tokens, keys i that also returns the exec of ProgramBlock