procc_ll::context

Struct Context

pub struct Context { /* private fields */ }
structure that contains all the data at the count level, saves the variables, tokens, functions and keys Use example :

 use processor::context::Context;
 let mut context = Context::new();
 context.push_key("key".to_owned(), |token, prog| {
    prog.exec(&token);
    processor::values::Values::Null
 });

Implementations

Source

impl Context

pub fn new<'b>() -> Context

Create a new instance of Context

pub fn token_index(&self, tok: &str) -> usize

Localize the index in the list of tokens of the token

PANICS

Return a panic if the token is not registered on the context

pub fn push_token(&mut self, tok: Box<dyn Token>)

Register a new token in te context

pub fn push_memory(&mut self, key: &str, tok: Values)

Push a new data on the memory

pub fn push_key( &mut self, key: String, tok: impl Fn(String, &mut ProgramBlock) -> Values + 'static, )

Register a new key

pub fn push_function( &mut self, name: String, func: impl Fn(String, &mut ProgramBlock) -> Values + 'static, )

Add a new function