pub trait Token {
// Required methods
fn exec(&self, input: &str, program: &mut ProgramBlock) -> Option<Values>;
fn is_token(&self, c: &str) -> bool;
}Expand description
trait that is used to define a structure, contains one method to run the token and another to verify that the token is compatible